from setuptools import setup

setup(
    name="arc-int",
    version="0.0.1",
    description="arc-int",
    author="Anish Agrawal",
    author_email="your.email@example.com",
    packages=["arc-int"],
)
